"""
Signal Processing Algorithms (:mod:`sigima.algorithms.signal`)
---------------------------------------------------------------

This package contains signal processing algorithms.

Algorithms are organized into subpackages according to their purpose:

- :mod:`sigima.algorithms.signal.dynamic`: Dynamic parameter extraction
- :mod:`sigima.algorithms.signal.fitmodels`: Curve fitting models
- :mod:`sigima.algorithms.signal.fourier`: Fourier analysis algorithms
- :mod:`sigima.algorithms.signal.interpolation`: Interpolation algorithms
- :mod:`sigima.algorithms.signal.level`: Level adjustment algorithms
- :mod:`sigima.algorithms.signal.misc`: Miscellaneous tools
- :mod:`sigima.algorithms.signal.peakdetection`: Peak detection algorithms
- :mod:`sigima.algorithms.signal.pulse`: Pulse analysis algorithms
- :mod:`sigima.algorithms.signal.stability`: Stability analysis algorithms
- :mod:`sigima.algorithms.signal.windowing`: Windowing algorithms


Dynamic Parameter Extraction
^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: sigima.algorithms.signal.dynamic
   :members:

Curve Fitting Models
^^^^^^^^^^^^^^^^^^^^

.. automodule:: sigima.algorithms.signal.fitmodels
   :members:

Fourier Analysis Algorithms
^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: sigima.algorithms.signal.fourier
   :members:

Interpolation Algorithms
^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: sigima.algorithms.signal.interpolation
   :members:

Scaling Algorithms
^^^^^^^^^^^^^^^^^^

.. automodule:: sigima.algorithms.signal.scaling
   :members:

Features
^^^^^^^^

.. automodule:: sigima.algorithms.signal.features
   :members:

Peak Detection Algorithms
^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: sigima.algorithms.signal.peakdetection
   :members:

Pulse Analysis Algorithms
^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: sigima.algorithms.signal.pulse
   :members:

Stability Analysis Algorithms
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: sigima.algorithms.signal.stability
   :members:

Windowing Algorithms
^^^^^^^^^^^^^^^^^^^^

.. automodule:: sigima.algorithms.signal.windowing
   :members:

"""
